==> google-cloud-run-0.4.0.tar.gz: google-cloud-run-0.4.0/google/cloud/run_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .condition import (
    Condition,
)
from .k8s_min import (
    CloudSqlInstance,
    Container,
    ContainerPort,
    EnvVar,
    EnvVarSource,
    ResourceRequirements,
    SecretKeySelector,
    SecretVolumeSource,
    VersionToPath,
    Volume,
    VolumeMount,
)
from .revision import (
    DeleteRevisionRequest,
    GetRevisionRequest,
    ListRevisionsRequest,
    ListRevisionsResponse,
    Revision,
)
from .revision_template import (
    RevisionTemplate,
)
from .service import (
    CreateServiceRequest,
    DeleteServiceRequest,
    GetServiceRequest,
    ListServicesRequest,
    ListServicesResponse,
    Service,
    UpdateServiceRequest,
)
from .traffic_target import (
    TrafficTarget,
    TrafficTargetStatus,
    TrafficTargetAllocationType,
)
from .vendor_settings import (
    BinaryAuthorization,
    RevisionScaling,
    VpcAccess,
    ExecutionEnvironment,
    IngressTraffic,
)

__all__ = (
    "Condition",
    "CloudSqlInstance",
    "Container",
    "ContainerPort",
    "EnvVar",
    "EnvVarSource",
    "ResourceRequirements",
    "SecretKeySelector",
    "SecretVolumeSource",
    "VersionToPath",
    "Volume",
    "VolumeMount",
    "DeleteRevisionRequest",
    "GetRevisionRequest",
    "ListRevisionsRequest",
    "ListRevisionsResponse",
    "Revision",
    "RevisionTemplate",
    "CreateServiceRequest",
    "DeleteServiceRequest",
    "GetServiceRequest",
    "ListServicesRequest",
    "ListServicesResponse",
    "Service",
    "UpdateServiceRequest",
    "TrafficTarget",
    "TrafficTargetStatus",
    "TrafficTargetAllocationType",
    "BinaryAuthorization",
    "RevisionScaling",
    "VpcAccess",
    "ExecutionEnvironment",
    "IngressTraffic",
)

==> google-cloud-run-0.6.0.tar.gz: google-cloud-run-0.6.0/google/cloud/run_v2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .condition import Condition
from .execution import (
    DeleteExecutionRequest,
    Execution,
    GetExecutionRequest,
    ListExecutionsRequest,
    ListExecutionsResponse,
)
from .execution_template import ExecutionTemplate
from .job import (
    CreateJobRequest,
    DeleteJobRequest,
    ExecutionReference,
    GetJobRequest,
    Job,
    ListJobsRequest,
    ListJobsResponse,
    RunJobRequest,
    UpdateJobRequest,
)
from .k8s_min import (
    CloudSqlInstance,
    Container,
    ContainerPort,
    EnvVar,
    EnvVarSource,
    GRPCAction,
    HTTPGetAction,
    HTTPHeader,
    Probe,
    ResourceRequirements,
    SecretKeySelector,
    SecretVolumeSource,
    TCPSocketAction,
    VersionToPath,
    Volume,
    VolumeMount,
)
from .revision import (
    DeleteRevisionRequest,
    GetRevisionRequest,
    ListRevisionsRequest,
    ListRevisionsResponse,
    Revision,
)
from .revision_template import RevisionTemplate
from .service import (
    CreateServiceRequest,
    DeleteServiceRequest,
    GetServiceRequest,
    ListServicesRequest,
    ListServicesResponse,
    Service,
    UpdateServiceRequest,
)
from .task import (
    GetTaskRequest,
    ListTasksRequest,
    ListTasksResponse,
    Task,
    TaskAttemptResult,
)
from .task_template import TaskTemplate
from .traffic_target import (
    TrafficTarget,
    TrafficTargetAllocationType,
    TrafficTargetStatus,
)
from .vendor_settings import (
    BinaryAuthorization,
    ExecutionEnvironment,
    IngressTraffic,
    RevisionScaling,
    VpcAccess,
)

__all__ = (
    "Condition",
    "DeleteExecutionRequest",
    "Execution",
    "GetExecutionRequest",
    "ListExecutionsRequest",
    "ListExecutionsResponse",
    "ExecutionTemplate",
    "CreateJobRequest",
    "DeleteJobRequest",
    "ExecutionReference",
    "GetJobRequest",
    "Job",
    "ListJobsRequest",
    "ListJobsResponse",
    "RunJobRequest",
    "UpdateJobRequest",
    "CloudSqlInstance",
    "Container",
    "ContainerPort",
    "EnvVar",
    "EnvVarSource",
    "GRPCAction",
    "HTTPGetAction",
    "HTTPHeader",
    "Probe",
    "ResourceRequirements",
    "SecretKeySelector",
    "SecretVolumeSource",
    "TCPSocketAction",
    "VersionToPath",
    "Volume",
    "VolumeMount",
    "DeleteRevisionRequest",
    "GetRevisionRequest",
    "ListRevisionsRequest",
    "ListRevisionsResponse",
    "Revision",
    "RevisionTemplate",
    "CreateServiceRequest",
    "DeleteServiceRequest",
    "GetServiceRequest",
    "ListServicesRequest",
    "ListServicesResponse",
    "Service",
    "UpdateServiceRequest",
    "GetTaskRequest",
    "ListTasksRequest",
    "ListTasksResponse",
    "Task",
    "TaskAttemptResult",
    "TaskTemplate",
    "TrafficTarget",
    "TrafficTargetStatus",
    "TrafficTargetAllocationType",
    "BinaryAuthorization",
    "RevisionScaling",
    "VpcAccess",
    "ExecutionEnvironment",
    "IngressTraffic",
)
